@@ -21,9 +21,9 @@ class Cache(objects.Object):
 		self.fp = self.file_path = FilePath(self.path)
 	def set(self, data=None, group=None, id=None, format="str"):
 		if id == None:
-			data_path = f"{self.path}/{group}"
+			data_path = gp.clean(f"{self.path}/{group}")
 		else:
-			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
+			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
 		base = FilePath(data_path).base()
 		if not gfp.exists(base): os.system(f"mkdir -p {base}")
 		if format in [str, "str", "string", int, float, "int", "integer", "float", "double"]:
@@ -32,11 +32,12 @@ class Cache(objects.Object):
 			Files.save(data_path, str(data), format="json")
 		else:
 			raise ValueError(f"Unkown format: {format}.")
+		return None
 	def get(self, group=None, id=None, format="str"):
 		if id == None:
-			data_path = f"{self.path}/{group}"
+			data_path = gp.clean(f"{self.path}/{group}")
 		else:
-			data_path = f"{self.path}/{group}/"+id.replace("/", "\\")
+			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
 		base = FilePath(data_path).base()
 		if not gfp.exists(base): os.system(f"mkdir -p {base}")
 		def load():
@@ -57,6 +58,13 @@ class Cache(objects.Object):
 			loaded = load()
 		if loaded in ["None","none","null"]: loaded = None
 		return loaded
+	def delete(self, group=None, id=None, forced=False, sudo=False):
+		if id == None:
+			data_path = gp.clean(f"{self.path}/{group}")
+		else:
+			data_path = gfp.clean(f"{self.path}/{group}/"+id)#.replace("/", "\\")
+		Files.delete(path=data_path, sudo=sudo, forced=forced)
+		return None
 
 
 # the default cache.
