@@ -3,10 +3,11 @@
 from syst3m.classes.config import *
 from syst3m.classes.color import color
 from syst3m.classes import defaults
+import getpass
 
 # input.
 _input_ = input
-def input(message, yes_no=False, check=False):
+def input(message, yes_no=False, check=False, password=False, default=None):
 	message = color.fill(message)
 	if len(message) > 0 and message[0].upper() != message[0]: message = String(message).capitalized_word()
 	if yes_no:
@@ -24,12 +25,23 @@ def input(message, yes_no=False, check=False):
 			if len(message) > 0 and message[len(message)-1] == " ": message = message[:-1]
 			elif len(message) > 0 and message[len(message)-1] == ":": message = message[:-1]
 			else: break
-		value = _input_(message+": ")
+		if password:
+			value = getpass.getpass(message+": ")
+		else:
+			value = _input_(message+": ")
+			if value in [""]: value = default
 		if check:
-			if input(f"({value}) correct?", yes_no=True):
-				return value
+			if password:
+				if getpass.getpass("Enter the same passphrase: ") != password:
+					print("Passphrases do not match.")
+					return default
+				else:
+					return password
 			else:
-				return None
+				if input(f"({value}) correct?", yes_no=True):
+					return value
+				else:
+					return default
 		else:
 			return value
 
