@@ -59,7 +59,7 @@ def alias(
 	if ((cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite) and present) or (present or not Files.exists(path)):
 		if l_alias != None: alias = l_alias
 		#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
-		sudo = Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
+		sudo = Boolean("--sudo" in sys.argv).string(true="sudo ",false="")
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
@@ -109,7 +109,7 @@ def kill(
 		if not response.success: return response
 		c = 0
 		for pid, info in response.processes.items():
-			response = self.kill(sudo=sudo, pid=pid, loader=loader)
+			response = kill(sudo=sudo, pid=pid, loader=loader)
 			if not response.success: return response
 			c += 1
 		if c == 0:
@@ -123,7 +123,7 @@ def kill(
 	else:
 		if log_level >= 0:
 			loader = console.Loader(f"Killing process {pid}.")
-		_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
+		_sudo_ = Boolean(sudo).string(true="sudo ", false="")
 		output = utils.__execute_script__(f"{_sudo_}kill {pid}")
 		if output in ["terminated",""]:
 			if output in [""]:
@@ -149,7 +149,7 @@ def processes(
 	# banned process names.
 	banned=["grep"],
 ):
-	_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
+	_sudo_ = Boolean(sudo).string(true="sudo ", false="")
 	if isinstance(includes, str):
 		command = f"""{_sudo_}ps -ax | grep "{includes}" | """
 	else:
