@@ -180,13 +180,14 @@ class Thread(Object, threading.Thread):
 		return self.__response__
 	# str representation.
 	def __str__(self):
+		error = None
 		if self.crashed:
 			try: error = self.response.error
 			except: error = None
 		if error != None:
-			return f"<{self.__traceback__()[1:-1]} (crashed: {crashed}) (error: {error}) >"
+			return f"<{self.__traceback__()[1:-1]} (crashed: {self.crashed}) (error: {error}) >"
 		else:
-			return f"<{self.__traceback__()[1:-1]} (running: {running}) (stopped: {stopped}) (crashed: {crashed}) >"
+			return f"<{self.__traceback__()[1:-1]} (running: {self.running}) (stopped: {self.stopped}) (crashed: {self.crashed}) >"
 	# representation.
 	def __repr__(self):
 		return str(self)
